==> owncloud-4.0.4.tgz: owncloud/apps/files/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Non hai erros, o ficheiro enviouse correctamente",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "O ficheiro enviado supera a directiva upload_max_filesize no php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "O ficheiro enviado supera a directiva MAX_FILE_SIZE que foi indicada no formulario HTML",
"The uploaded file was only partially uploaded" => "O ficheiro enviado foi só parcialmente enviado",
"No file was uploaded" => "Non se enviou ningún ficheiro",
"Missing a temporary folder" => "Falta un cartafol temporal",
"Failed to write to disk" => "Erro ao escribir no disco",
"Files" => "Ficheiros",
"Size" => "Tamaño",
"Modified" => "Modificado",
"File handling" => "Manexo de ficheiro",
"Maximum upload size" => "Tamaño máximo de envío",
"max. possible: " => "máx. posible: ",
"Needed for multi-file and folder downloads." => "Preciso para descarga de varios ficheiros e cartafoles.",
"Enable ZIP-download" => "Habilitar a descarga-ZIP",
"0 is unlimited" => "0 significa ilimitado",
"Maximum input size for ZIP files" => "Tamaño máximo de descarga para os ZIP",
"New" => "Novo",
"Text file" => "Ficheiro de texto",
"Folder" => "Cartafol",
"From url" => "Desde url",
"Upload" => "Enviar",
"Cancel upload" => "Cancelar subida",
"Nothing in here. Upload something!" => "Nada por aquí. Envíe algo.",
"Name" => "Nome",
"Share" => "Compartir",
"Download" => "Descargar",
"Delete" => "Eliminar",
"Upload too large" => "Envío demasiado grande",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Os ficheiros que trata de subir superan o tamaño máximo permitido neste servidor",
"Files are being scanned, please wait." => "Estanse analizando os ficheiros, espere por favor.",
"Current scanning" => "Análise actual."
);

==> owncloud-4.5.7.tgz: owncloud/apps/files/l10n/gl.php <==
<?php $TRANSLATIONS = array(
"There is no error, the file uploaded with success" => "Non hai erros, o ficheiro enviouse correctamente",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "O ficheiro enviado supera a directiva upload_max_filesize no php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "O ficheiro enviado supera a directiva MAX_FILE_SIZE que foi indicada no formulario HTML",
"The uploaded file was only partially uploaded" => "O ficheiro enviado foi só parcialmente enviado",
"No file was uploaded" => "Non se enviou ningún ficheiro",
"Missing a temporary folder" => "Falta un cartafol temporal",
"Failed to write to disk" => "Erro ao escribir no disco",
"Files" => "Ficheiros",
"Unshare" => "Deixar de compartir",
"Delete" => "Eliminar",
"already exists" => "xa existe",
"replace" => "substituír",
"suggest name" => "suxira nome",
"cancel" => "cancelar",
"replaced" => "substituído",
"undo" => "desfacer",
"with" => "con",
"unshared" => "non compartido",
"deleted" => "eliminado",
"generating ZIP-file, it may take some time." => "xerando ficheiro ZIP, pode levar un anaco.",
"Unable to upload your file as it is a directory or has 0 bytes" => "Non se puido subir o ficheiro pois ou é un directorio ou ten 0 bytes",
"Upload Error" => "Erro na subida",
"Pending" => "Pendentes",
"Upload cancelled." => "Subida cancelada.",
"File upload is in progress. Leaving the page now will cancel the upload." => "A subida do ficheiro está en curso. Saír agora da páxina cancelará a subida.",
"Invalid name, '/' is not allowed." => "Nome non válido, '/' non está permitido.",
"files scanned" => "ficheiros analizados",
"error while scanning" => "erro mentras analizaba",
"Name" => "Nome",
"Size" => "Tamaño",
"Modified" => "Modificado",
"folder" => "cartafol",
"folders" => "cartafoles",
"file" => "ficheiro",
"files" => "ficheiros",
"File handling" => "Manexo de ficheiro",
"Maximum upload size" => "Tamaño máximo de envío",
"max. possible: " => "máx. posible: ",
"Needed for multi-file and folder downloads." => "Preciso para descarga de varios ficheiros e cartafoles.",
"Enable ZIP-download" => "Habilitar a descarga-ZIP",
"0 is unlimited" => "0 significa ilimitado",
"Maximum input size for ZIP files" => "Tamaño máximo de descarga para os ZIP",
"Save" => "Gardar",
"New" => "Novo",
"Text file" => "Ficheiro de texto",
"Folder" => "Cartafol",
"From url" => "Desde url",
"Upload" => "Enviar",
"Cancel upload" => "Cancelar subida",
"Nothing in here. Upload something!" => "Nada por aquí. Envíe algo.",
"Share" => "Compartir",
"Download" => "Descargar",
"Upload too large" => "Envío demasiado grande",
"The files you are trying to upload exceed the maximum size for file uploads on this server." => "Os ficheiros que trata de subir superan o tamaño máximo permitido neste servidor",
"Files are being scanned, please wait." => "Estanse analizando os ficheiros, espere por favor.",
"Current scanning" => "Análise actual."
);
